@@ -82,7 +82,7 @@ class CatalogPrivate;
 */
 struct DocPosition
 {
-	DocPosition( ) : offset(0), item(0), form(0) { }
+	DocPosition( ) : offset(0), part(UndefPart), item(0), form(0) { }
 	uint offset;
 	
 	Part part;
