@@ -1,10 +1,9 @@
 /* ****************************************************************************
   This file is part of KBabel
 
-  Copyright (C) 1999-2000 by Matthias Kiefer
-                            <matthias.kiefer@gmx.de>
-		2002	  by Stanislav Visnovsky
-			    <visnovsky@nenya.ms.mff.cuni.cz>
+  Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
+		2002	  by Stanislav Visnovsky <visnovsky@nenya.ms.mff.cuni.cz>
+  Copyright (C) 2006 by Nicolas GOUTTE <goutte@kde.org> 
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -208,29 +207,29 @@ QStringList CatalogItem::argList( RegExpExtractor& te)
 
 bool CatalogItem::isFuzzy() const
 {
-   bool flag=false;
-   if( d->_comment.contains( QRegExp(",\\s*fuzzy") ) )
-     flag=true;
-
-   return flag;
+    return d->_comment.find( QRegExp(",\\s*fuzzy") ) != -1;
 }
 
 bool CatalogItem::isCformat() const
 {
-   bool flag=false;
-   if(d->_comment.contains( QRegExp(",\\s*c-format")))
-     flag=true;
-
-   return flag;
+    // Allow "possible-c-format" (from xgettext --debug) or "c-format"
+    // Note the regexp (?: ) is similar to () but it does not capture (so it is faster)
+    return d->_comment.find( QRegExp(",\\s*(?:possible-)c-format") ) == -1;
 }
 
 bool CatalogItem::isNoCformat() const
 {
-   bool flag=false;
-   if(d->_comment.contains( QRegExp(",\\s*no-c-format")))
-     flag=true;
+    return d->_comment.find( QRegExp(",\\s*no-c-format") ) == -1;
+}
 
-   return flag;
+bool CatalogItem::isQtformat() const
+{
+    return d->_comment.find( QRegExp(",\\s*qt-format") ) == -1;
+}
+
+bool CatalogItem::isNoQtformat() const
+{
+    return d->_comment.find( QRegExp(",\\s*no-qt-format") ) == -1;
 }
 
 bool CatalogItem::isUntranslated() const
@@ -240,9 +239,12 @@ bool CatalogItem::isUntranslated() const
 
 PluralFormType CatalogItem::pluralForm() const
 {
-    if( d->_gettextPluralForm ) return Gettext;
-    if( d->_msgid.first().find( QRegExp("_n:\\s")) == 0 ) return KDESpecific; // ### TODO: we could use startsWith("_n: ")
-    else return NoPluralForm;
+    if( d->_gettextPluralForm )
+        return Gettext;
+    if( d->_msgid.first().startsWith( "_n: " ) )
+        return KDESpecific;
+    else
+        return NoPluralForm;
 }
 
 int CatalogItem::totalLines() const
