@@ -47,7 +47,7 @@
  *
  ***************************************************/
 
-K_EXPORT_COMPONENT_FACTORY( kbabel_argstool, KGenericFactory<ArgumentTool> )
+K_EXPORT_COMPONENT_FACTORY( kbabel_argstool, KGenericFactory<ArgumentTool> ( "kbabeldatatool" ) )
 
 using namespace KBabel;
 
