@@ -8,15 +8,20 @@
  *  copyright (C) 2003-2006                                                *
  *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
  ***************************************************************************/
+
+// own header
+#include "association.h"
+// qt/kde includes
 #include <kdebug.h>
 #include <klocale.h>
 #include <qregexp.h>
-
-#include "association.h"
+// app includes
 #include "classifier.h"
+#include "folder.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlrole.h"
+#include "uniqueid.h"
 #include "model_utils.h"
 
 using namespace Uml;
@@ -33,9 +38,9 @@ UMLAssociation::UMLAssociation( Association_Type type,
         : UMLObject("")
 {
     init(type, roleA, roleB);
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
-    m_pRole[Uml::A]->setID( pDoc->getUniqueID() );
-    m_pRole[Uml::B]->setID( pDoc->getUniqueID() );
+
+    m_pRole[Uml::A]->setID( UniqueID::gen() );
+    m_pRole[Uml::B]->setID( UniqueID::gen() );
 }
 
 UMLAssociation::UMLAssociation( Association_Type type /* = Uml::at_Unknown */)
@@ -549,7 +554,7 @@ void UMLAssociation::init(Association_Type type, UMLObject *roleAObj, UMLObject
     m_Name = "";
     m_bOldLoadMode = false;
     nrof_parent_widgets = -1;
-
+    m_pUMLPackage = UMLApp::app()->getDocument()->currentRoot();
     m_pRole[Uml::A] = new UMLRole (this, roleAObj, Uml::A);
     m_pRole[Uml::B] = new UMLRole (this, roleBObj, Uml::B);
 }
