@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
  ***************************************************************************/
 
 #include <kdebug.h>
@@ -31,6 +28,7 @@
 #include "../umlview.h"
 #include "../umlwidget.h"
 #include "../uml.h"
+#include "../model_utils.h"
 
 UMLClipboard::UMLClipboard() {
     m_type = clip1;
@@ -169,7 +167,7 @@ bool UMLClipboard::fillSelectionLists(UMLListViewItemList& SelectedItems) {
         for ( ; it.current(); ++it ) {
             item = (UMLListViewItem*)it.current();
             type = item->getType();
-            if ( !UMLListView::typeIsClassifierList(type) ) {
+            if ( !Model_Utils::typeIsClassifierList(type) ) {
                 m_ItemList.append(item);
                 insertItemChildren(item, SelectedItems);
                 //Because it is being called when m_type is 3
@@ -186,11 +184,11 @@ bool UMLClipboard::fillSelectionLists(UMLListViewItemList& SelectedItems) {
         for ( ; it.current(); ++it ) {
             item = (UMLListViewItem*)it.current();
             type = item->getType();
-            if ( !UMLListView::typeIsClassifierList(type) ) {
+            if ( !Model_Utils::typeIsClassifierList(type) ) {
 
                 m_ItemList.append(item);
 
-                if ( UMLListView::typeIsCanvasWidget(type) ) {
+                if ( Model_Utils::typeIsCanvasWidget(type) ) {
                     m_ObjectList.append(item->getUMLObject());
                 }
                 insertItemChildren(it.current(), SelectedItems);
@@ -201,7 +199,7 @@ bool UMLClipboard::fillSelectionLists(UMLListViewItemList& SelectedItems) {
         for ( ; it.current(); ++it ) {
             item = (UMLListViewItem*)it.current();
             type = item->getType();
-            if( UMLListView::typeIsClassifierList(type) ) {
+            if( Model_Utils::typeIsClassifierList(type) ) {
                 m_ItemList.append(item);
                 m_ObjectList.append(item->getUMLObject());
 
@@ -244,15 +242,15 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* Item, bool & WithDiagra
     UMLView * view = 0;
     UMLListViewItem * child = 0;
     Uml::ListView_Type type = Item->getType();
-    if ( UMLListView::typeIsCanvasWidget(type) ) {
+    if ( Model_Utils::typeIsCanvasWidget(type) ) {
         WithObjects = true;
         OnlyAttsOps = false;
-    } else if ( UMLListView::typeIsDiagram(type) ) {
+    } else if ( Model_Utils::typeIsDiagram(type) ) {
         WithDiagrams = true;
         OnlyAttsOps = false;
         view = doc->findView( Item->getID() );
         m_ViewList.append( view );
-    } else if ( UMLListView::typeIsFolder(type) ) {
+    } else if ( Model_Utils::typeIsFolder(type) ) {
         OnlyAttsOps = false;
         if(Item->childCount()) {
             child = (UMLListViewItem*)Item->firstChild();
@@ -476,7 +474,7 @@ bool UMLClipboard::pasteClip4(QMimeSource* data) {
         return false;
     }
 
-    if( diagramType != doc->getCurrentView()->getType() ) {
+    if( diagramType != UMLApp::app()->getCurrentView()->getType() ) {
         if( !checkPasteWidgets(widgets) ) {
             assocs.setAutoDelete(true);
             assocs.clear();
@@ -500,18 +498,19 @@ bool UMLClipboard::pasteClip4(QMimeSource* data) {
 
     //now add any widget we are want to paste
     bool objectAlreadyExists = false;
-    doc->getCurrentView()->beginPartialWidgetPaste();
+    UMLView *currentView = UMLApp::app()->getCurrentView();
+    currentView->beginPartialWidgetPaste();
     UMLWidget* widget =0;
     UMLWidgetListIt widget_it(widgets);
     while ( (widget=widget_it.current()) != 0 ) {
         ++widget_it;
 
-        if (doc->getCurrentView()->findWidget(idchanges->findNewID(widget->getID()))) {
+        if (currentView->findWidget(idchanges->findNewID(widget->getID()))) {
             objectAlreadyExists = true;
         }
 
-        if ( !doc->getCurrentView()->addWidget(widget, true) ) {
-            doc->getCurrentView()->endPartialWidgetPaste();
+        if ( !currentView->addWidget(widget, true) ) {
+            currentView->endPartialWidgetPaste();
             return false;
         }
     }
@@ -521,15 +520,15 @@ bool UMLClipboard::pasteClip4(QMimeSource* data) {
     AssociationWidgetListIt assoc_it(assocs);
     while ( (assoc=assoc_it.current()) != 0 ) {
         ++assoc_it;
-        if( !doc->getCurrentView()->addAssociation(assoc, true) ) {
-            doc->getCurrentView()->endPartialWidgetPaste();
+        if (!currentView->addAssociation(assoc, true)) {
+            currentView->endPartialWidgetPaste();
             return false;
         }
     }
 
     //Activate all the pasted associations and widgets
-    doc->getCurrentView()->activate();
-    doc->getCurrentView()->endPartialWidgetPaste();
+    currentView->activate();
+    currentView->endPartialWidgetPaste();
 
     UMLListView *listView = UMLApp::app()->getListView();
     UMLListViewItem* item = 0;
@@ -666,8 +665,8 @@ bool UMLClipboard::checkPasteWidgets( UMLWidgetList & widgetList ) {
 }
 
 void UMLClipboard::pasteItemAlreadyExists() {
-    UMLDoc *doc = UMLApp::app()->getDocument();
-    KMessageBox::sorry( doc->getCurrentView(),
+    UMLView *currentView = UMLApp::app()->getCurrentView();
+    KMessageBox::sorry( currentView,
                         i18n("At least one of the items in the clipboard "
                              "could not be pasted because an item of the "
                              "same name already exists.  Any other items "
