@@ -29,6 +29,9 @@
 #include "../operation.h"
 #include "../attribute.h"
 
+QStringList JavaImport::s_filesAlreadyParsed;
+int JavaImport::s_parseDepth = 0;
+
 JavaImport::JavaImport() : NativeImportBase("//") {
     setMultiLineComment("/*", "*/");
     initVars();
@@ -42,8 +45,7 @@ void JavaImport::initVars() {
 }
 
 /// Catenate possible template arguments/array dimensions to the end of the type name.
-QString JavaImport::joinTypename() {
-    QString typeName = m_source[m_srcIndex];
+QString JavaImport::joinTypename(QString typeName) {
     if (m_source[m_srcIndex + 1] == "<" ||
         m_source[m_srcIndex + 1] == "[") {
         uint start = ++m_srcIndex;
@@ -53,26 +55,19 @@ QString JavaImport::joinTypename() {
             typeName += m_source[i];
         }
     }
+    // to handle multidimensional arrays, call recursively
+    if (m_source[m_srcIndex + 1] == "[") {
+        typeName = joinTypename( typeName );
+    }
     return typeName;
 }
 
 void JavaImport::fillSource(QString word) {
     QString lexeme;
     const uint len = word.length();
-    bool inString = false;
     for (uint i = 0; i < len; i++) {
         const QChar& c = word[i];
-        if (c == '"') {
-            lexeme += c;
-            if (i == 0 || word[i - 1] != '\\') {
-                if (inString) {
-                    m_source.append(lexeme);
-                    lexeme = QString::null;
-                }
-                inString = !inString;
-            }
-        } else if (inString ||
-                   c.isLetterOrNumber() || c == '_' || c == '.') {
+        if (c.isLetterOrNumber() || c == '_' || c == '.') {
             lexeme += c;
         } else {
             if (!lexeme.isEmpty()) {
@@ -86,63 +81,20 @@ void JavaImport::fillSource(QString word) {
         m_source.append(lexeme);
 }
 
-bool JavaImport::skipToClosing(QChar opener) {
-    QString closing;
-    switch (opener) {
-        case '{':
-            closing = "}";
-            break;
-        case '[':
-            closing = "]";
-            break;
-        case '(':
-            closing = ")";
-            break;
-        case '<':
-            closing = ">";
-            break;
-        default:
-            kdError() << "JavaImport::skipToClosing(" << opener
-                << "): " << "illegal input character" << endl;
-            return false;
-    }
-    const QString opening(opener);
-    skipStmt(opening);
-    const uint srcLength = m_source.count();
-    int nesting = 0;
-    while (m_srcIndex < srcLength) {
-        QString nextToken = advance();
-        if (nextToken.isEmpty())
-            break;
-        if (nextToken == closing) {
-            if (nesting <= 0)
-                break;
-            nesting--;
-        } else if (nextToken == opening) {
-            nesting++;
-        }
-    }
-    if (m_srcIndex == srcLength)
-        return false;
-    return true;
-}
-
 
 ///Spawn off an import of the specifed file
 void JavaImport::spawnImport( QString file ) {
-    static QStringList filesBeingParsed;
     // if the file is being parsed, don't bother
     //
-    if (filesBeingParsed.contains( file ) ) {
+    if (s_filesAlreadyParsed.contains( file ) ) {
         return;
     }
     if (QFile::exists(file)) {
           JavaImport importer;
           QStringList fileList;
           fileList.append( file );
-          filesBeingParsed.append( file );
+          s_filesAlreadyParsed.append( file );
           importer.importFiles( fileList ); 
-          filesBeingParsed.remove( file );
     }
 }
 
@@ -157,6 +109,16 @@ UMLObject* findObject( QString name,   UMLPackage *parentPkg ) {
 
 ///Resolve the specified className 
 UMLObject* JavaImport::resolveClass (QString className) {
+    kdDebug() << "importJava trying to resolve " << className << endl; 
+    // keep track if we are dealing with an array
+    //
+    bool isArray = className.contains('[');
+    // remove any [] so that the class itself can be resolved
+    //
+    QString baseClassName = className;
+    baseClassName.remove('[');
+    baseClassName.remove(']');
+
     // java has a few implicit imports.  Most relevant for this is the 
     // current package, which is in the same directory as the current file
     // being parsed
@@ -171,10 +133,15 @@ UMLObject* JavaImport::resolveClass (QString className) {
     // current class
     //
     QString myDir = file.join( "/" );
-    QString myFile = "/" + myDir + "/" + className + ".java";
+    QString myFile = "/" + myDir + "/" + baseClassName + ".java";
     if ( QFile::exists(myFile) ) {
         spawnImport( myFile );
-        return findObject ( className, m_scope[m_scopeIndex]);
+        if ( isArray ) {
+            // we have imported the type. For arrays we want to return 
+            // the array type
+            return Import_Utils::createUMLObject(Uml::ot_Class, className, m_scope[m_scopeIndex]);
+        }
+        return findObject(baseClassName, m_scope[m_scopeIndex]);
     }
 
     // the class we want is not in the same package as the one being imported.
@@ -196,11 +163,11 @@ UMLObject* JavaImport::resolveClass (QString className) {
         QString import = (*pathIt);
         QStringList split = QStringList::split( '.', import );
         split.pop_back(); // remove the * or the classname
-        if ( import.endsWith( "*" ) || import.endsWith( className) ) {
+        if ( import.endsWith( "*" ) || import.endsWith( baseClassName) ) {
             // check if the file we want is in this imported package
             // convert the org.test type package into a filename
             //
-            QString aFile = sourceRoot + split.join("/") + "/" + className + ".java";
+            QString aFile = sourceRoot + split.join("/") + "/" + baseClassName + ".java";
             if ( QFile::exists(aFile) ) {
                 spawnImport( aFile );
                 // we need to set the package for the class that will be resolved
@@ -211,13 +178,17 @@ UMLObject* JavaImport::resolveClass (QString className) {
                 for (QStringList::Iterator it = split.begin(); it != split.end(); ++it) {
                     QString name = (*it);
                     UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Package,
-                            name, parent);
+                                                                  name, parent);
                     current = static_cast<UMLPackage*>(ns);
                     parent = current;
                 } // for
+                if ( isArray ) {
+                    // we have imported the type. For arrays we want to return 
+                    // the array type
+                    return Import_Utils::createUMLObject(Uml::ot_Class, className, current);
+                }
                 // now that we have the right package, the class should be findable
-                //
-                return findObject ( className, current);
+                return findObject(baseClassName, current);
             } // if file exists
         } // if import matches
     } //foreach import
@@ -229,7 +200,22 @@ UMLObject* JavaImport::resolveClass (QString className) {
 void JavaImport::parseFile(QString filename) {
     m_currentFileName= filename;
     m_imports.clear();
+    // default visibility is Impl, unless we are an interface, then it is 
+    // public for member vars and methods
+    m_defaultCurrentAccess = Uml::Visibility::Implementation;
+    m_currentAccess = m_defaultCurrentAccess;
+    s_parseDepth++;
+    // in the case of self referencing types, we can avoid parsing the 
+    // file twice by adding it to the list
+    s_filesAlreadyParsed.append(filename);
     NativeImportBase::parseFile(filename);
+    s_parseDepth--;
+    if ( s_parseDepth <= 0 ) {
+        // if the user decides to clear things out and reparse, we need
+        // to honour the request, so reset things for next time.
+        s_filesAlreadyParsed.clear();
+        s_parseDepth = 0;
+    }
 }
 
 
@@ -253,9 +239,6 @@ bool JavaImport::parseStmt() {
             kdError() << "importJava: unexpected: " << m_source[m_srcIndex] << endl;
             skipStmt();
         }
-        // The default visibilty for java is implementation, since the absence
-        // of a modifier means package visibility (which maps to implementation).
-        m_currentAccess = Uml::Visibility::Implementation;
         return true;
     }
     if (keyword == "class" || keyword == "interface") {
@@ -271,6 +254,10 @@ bool JavaImport::parseStmt() {
         // change it.
         m_klass->setInterface(keyword == "interface");
         m_isAbstract = m_isStatic = false;
+        // if no modifier is specified in an interface, then it means public
+        if ( m_klass->isInterface() ) {
+            m_defaultCurrentAccess =  Uml::Visibility::Public;
+        }
         if (advance() == ";")   // forward declaration
             return true;
         if (m_source[m_srcIndex] == "<") {
@@ -302,7 +289,7 @@ bool JavaImport::parseStmt() {
         }
         if (m_source[m_srcIndex] == "extends") {
             const QString& baseName = advance();
-            // try to resove the class we are extending, or if impossible
+            // try to resolve the class we are extending, or if impossible
             // create a placeholder
             UMLObject *parent = resolveClass( baseName );
             if ( parent ) {
@@ -369,6 +356,12 @@ bool JavaImport::parseStmt() {
         m_isStatic = true;
         return true;
     }
+    // if we detected static previously and keyword is { then this is a static block
+    if (m_isStatic && keyword == "{") {
+        // reset static flag and jump to end of static block
+        m_isStatic = false;
+        return skipToClosing('{');
+    }
     if (keyword == "abstract") {
         m_isAbstract = true;
         return true;
@@ -430,7 +423,8 @@ bool JavaImport::parseStmt() {
         kdError() << "importJava: ignoring " << keyword << endl;
         return false;
     }
-    QString typeName = joinTypename();
+    QString typeName = m_source[m_srcIndex];
+    typeName = joinTypename(typeName);
     // At this point we need a class.
     if (m_klass == NULL) {
         kdError() << "importJava: no class set for " << typeName << endl;
@@ -455,19 +449,36 @@ bool JavaImport::parseStmt() {
         UMLOperation *op = Import_Utils::makeOperation(m_klass, name);
         m_srcIndex++;
         while (m_srcIndex < srcLength && m_source[m_srcIndex] != ")") {
-            QString typeName = joinTypename();
+            QString typeName = m_source[m_srcIndex];
+            if ( typeName == "final" || typeName.startsWith( "//") ) {
+                // ignore the "final" keyword and any comments in method args
+                typeName = advance();
+            } 
+            typeName = joinTypename(typeName);
             QString parName = advance();
-            UMLAttribute *att = Import_Utils::addMethodParameter(op, typeName, parName);
+            // the Class might not be resolved yet so resolve it if necessary
+            UMLObject *obj = resolveClass(typeName);
+            if (obj) {
+                // by prepending the package, unwanted placeholder types will not get created
+                typeName = obj->getFullyQualifiedName(".");
+            }
+            /* UMLAttribute *att = */ Import_Utils::addMethodParameter(op, typeName, parName);
             if (advance() != ",")
                 break;
             m_srcIndex++;
         }
+        // before adding the method, try resolving the return type
+        UMLObject *obj = resolveClass(typeName);
+        if (obj) {
+            // using the fully qualified name means that a placeholder type will not be created.
+            typeName = obj->getFullyQualifiedName(".");
+        }
         Import_Utils::insertMethod(m_klass, op, m_currentAccess, typeName,
                                    m_isStatic, m_isAbstract, false /*isFriend*/,
                                    false /*isConstructor*/, m_comment);
         m_isAbstract = m_isStatic = false;
-        // Default visibility for java is implementation (package vis.)
-        m_currentAccess = Uml::Visibility::Implementation;
+        // reset the default visibility
+        m_currentAccess = m_defaultCurrentAccess;
         // At this point we do not know whether the method has a body or not.
         do {
             nextToken = advance();
@@ -516,7 +527,7 @@ bool JavaImport::parseStmt() {
             o = Import_Utils::insertAttribute(m_klass, m_currentAccess, name,
                                                   typeName, m_comment, m_isStatic);
         }
-        UMLAttribute *attr = static_cast<UMLAttribute*>(o);
+        // UMLAttribute *attr = static_cast<UMLAttribute*>(o);
         if (nextToken != ",") {
             // reset the modifiers
             m_isStatic = m_isAbstract = false;
@@ -526,7 +537,7 @@ bool JavaImport::parseStmt() {
         nextToken = advance();
     }
     // reset visibility to default
-    m_currentAccess = Uml::Visibility::Implementation;
+    m_currentAccess = m_defaultCurrentAccess;
     if (m_source[m_srcIndex] != ";") {
         kdError() << "importJava: ignoring trailing items at " << name << endl;
         skipStmt();
