@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *  copyright (C) 2003-2006                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -17,7 +14,7 @@
 
 // qt includes
 #include <qlayout.h>
-#include <qcombobox.h>
+#include <kcombobox.h>
 
 // kde includes
 #include <klocale.h>
@@ -91,7 +88,7 @@ void AssocGenPage::constructWidget() {
 
     bool found=false;
     m_AssocTypeStrings.clear();
-    for (int i=0; i<m_AssocTypes.size(); ++i) {
+    for (uint i=0; i<m_AssocTypes.size(); ++i) {
         if (m_AssocTypes[i] == currentType) found=true;
         QString typeStr = UMLAssociation::typeAsString(m_AssocTypes[i]);
         m_AssocTypeStrings << typeStr;
@@ -104,10 +101,13 @@ void AssocGenPage::constructWidget() {
         m_AssocTypeStrings << currentTypeAsString;
     }
     
-    m_pTypeCB = new QComboBox(nameGB);
+    m_pTypeCB = new KComboBox(nameGB);
     pTypeL->setBuddy(m_pTypeCB);
     m_pTypeCB->insertStringList(m_AssocTypeStrings);
+    m_pTypeCB->setCompletedItems(m_AssocTypeStrings);
     m_pTypeCB->setCurrentText(currentTypeAsString);
+    m_pTypeCB->setDuplicatesEnabled(false);//only allow one of each type in box
+    m_pTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
     m_pDoc->setWordWrap(QMultiLineEdit::WidgetWidth);
     nameLayout->addWidget(m_pTypeCB, 1, 1);
     
