@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
  ***************************************************************************/
 
 // own header
@@ -52,10 +49,12 @@ void AssocRolePage::constructWidget() {
     QString nameB = m_pAssociationWidget->getRoleName(Uml::B);
     QString titleA = i18n("Role A Properties");
     QString titleB = i18n("Role B Properties");
-    if(!nameA.isEmpty())
-        titleA.append( "("+nameA+")");
-    if(!nameB.isEmpty())
-        titleB.append( "("+nameB+")");
+    QString widgetNameA = m_pAssociationWidget->getWidget(Uml::A)->getName();
+    QString widgetNameB = m_pAssociationWidget->getWidget(Uml::B)->getName();
+    if(!widgetNameA.isEmpty())
+        titleA.append(" (" + widgetNameA + ")");
+    if(!widgetNameB.isEmpty())
+        titleB.append(" (" + widgetNameB + ")");
 
     // general configuration of the GUI
     int margin = fontMetrics().height();
@@ -183,7 +182,7 @@ void AssocRolePage::constructWidget() {
 
     m_ImplementationBRB = new QRadioButton(i18n("Implementation"), scopeBBG);
     scopeBLayout -> addWidget(m_ImplementationBRB);
-    
+
     scope = m_pAssociationWidget->getVisibility(Uml::B);
     if( scope == Uml::Visibility::Public )
         m_PublicBRB -> setChecked( true );
