@@ -29,6 +29,7 @@
 #include "uml.h"
 #include "model_utils.h"
 #include "widget_utils.h"
+#include "folder.h"
 #include "umlview.h"
 #include "statewidget.h"
 #include "activitywidget.h"
@@ -638,7 +639,19 @@ void ListPopupMenu::insertSubmodelAction() {
     }
     UMLListView *listView = UMLApp::app()->getListView();
     UMLListViewItem *current = static_cast<UMLListViewItem*>(listView->currentItem());
-    QString submodelFile = current->getFolderFile();
+    UMLObject *o = current->getUMLObject();
+    if (o == NULL) {
+        kdError() << "ListPopupMenu::insertSubmodelAction: "
+            << current->getText() << " getUMLObject()  returns NULL" << endl;
+        return;
+    }
+    UMLFolder *f = dynamic_cast<UMLFolder*>(o);
+    if (f == NULL) {
+        kdError() << "ListPopupMenu::insertSubmodelAction: "
+            << "current->getUMLObject (" << o->getName() << ") is not a Folder" << endl;
+        return;
+    }
+    QString submodelFile = f->getFolderFile();
     if (submodelFile.isEmpty())
         insertStdItem(mt_Externalize_Folder);
     else
@@ -738,7 +751,7 @@ void ListPopupMenu::setupColorSelection(bool fc)
 }
 
 Uml::Diagram_Type ListPopupMenu::convert_MT_DT(Menu_Type mt) {
-    Uml::Diagram_Type type =  Uml::dt_Class;
+    Uml::Diagram_Type type =  Uml::dt_Undefined;
 
     switch(mt) {
     case mt_UseCase_Diagram:
@@ -759,6 +772,12 @@ Uml::Diagram_Type ListPopupMenu::convert_MT_DT(Menu_Type mt) {
     case mt_Activity_Diagram:
         type = Uml::dt_Activity;
         break;
+    case mt_Component_Diagram:
+        type = Uml::dt_Component;
+        break;
+    case mt_Deployment_Diagram:
+        type = Uml::dt_Deployment;
+        break;
     case mt_EntityRelationship_Diagram:
         type = Uml::dt_EntityRelationship;
         break;
