@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
  ***************************************************************************/
 
 
@@ -66,10 +63,6 @@ void UMLStereotype::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
     qElement.appendChild( stereotypeElement );
 }
 
-bool UMLStereotype::load(QDomElement& /*element*/) {
-    return true;
-}
-
 bool UMLStereotype::showPropertiesDialogue(QWidget* parent) {
     bool ok;
     QString name = KInputDialog::getText(i18n("Stereotype"), i18n("Enter name:"), getName(),&ok, parent);
