@@ -44,7 +44,6 @@
 
 // app includes
 #include "aligntoolbar.h"
-#include "infowidget.h"
 #include "codeimport/classimport.h"
 #include "docwindow.h"
 #include "codegenerator.h"
@@ -78,6 +77,9 @@
 
 #include "cmdlineexportallviewsevent.h"
 
+#include "docgenerators/docbookgenerator.h"
+#include "docgenerators/xhtmlgenerator.h"
+
 UMLApp::UMLApp(QWidget* , const char* name):KDockMainWindow(0, name) {
     s_instance = this;
     m_pDocWindow = 0;
@@ -91,11 +93,13 @@ UMLApp::UMLApp(QWidget* , const char* name):KDockMainWindow(0, name) {
     m_codegen = 0;
     m_policyext = 0;
     m_commoncodegenpolicy = 0;
+    m_xhtmlGenerator = 0;
     m_activeLanguage = Uml::pl_Reserved;
     ///////////////////////////////////////////////////////////////////
     // call inits to invoke all other construction parts
     readOptionState();
     m_doc = new UMLDoc();
+    m_doc->init();
     initActions(); //now calls initStatusBar() because it is affected by setupGUI()
     initView();
     initClip();
@@ -179,7 +183,13 @@ void UMLApp::initActions() {
     viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
 #endif
     selectAll = KStdAction::selectAll(this,  SLOT( slotSelectAll() ), actionCollection());
-
+    fileExportDocbook = new KAction(i18n("&Export model to DocBook"), 0, 
+                                    this, SLOT( slotFileExportDocbook() ), 
+                                    actionCollection(), "file_export_docbook");
+    fileExportXhtml = new KAction(i18n("&Export model to XHTML"), 0, 
+                                    this, SLOT( slotFileExportXhtml() ),
+                                    actionCollection(), "file_export_xhtml");
+    
     classWizard = new KAction(i18n("&New Class Wizard..."),0,this,SLOT(slotClassWizard()),
                               actionCollection(),"class_wizard");
     new KAction(i18n("&Add Default Datatypes for Active Language"), 0, this,
@@ -203,6 +213,8 @@ void UMLApp::initActions() {
     fileClose->setToolTip(i18n("Closes the document"));
     filePrint ->setToolTip(i18n("Prints out the document"));
     fileQuit->setToolTip(i18n("Quits the application"));
+    fileExportDocbook->setToolTip(i18n("Exports the model to the docbook format"));
+    fileExportXhtml->setToolTip(i18n("Exports the model to the XHTML format"));
     editCut->setToolTip(i18n("Cuts the selected section and puts it to the clipboard"));
     editCopy->setToolTip(i18n("Copies the selected section to the clipboard"));
     editPaste->setToolTip(i18n("Pastes the contents of the clipboard"));
@@ -328,7 +340,7 @@ void UMLApp::initActions() {
 
 void UMLApp::slotZoomSliderMoved(int value) {
     int zoom = (int)(value*0.01);
-    m_doc->getCurrentView()->setZoom(zoom*zoom);
+    getCurrentView()->setZoom(zoom*zoom);
 }
 
 void UMLApp::slotZoom100()  {
@@ -336,7 +348,7 @@ void UMLApp::slotZoom100()  {
 }
 
 void UMLApp::setZoom(int zoom) {
-    m_doc->getCurrentView()->setZoom(zoom);
+    getCurrentView()->setZoom(zoom);
 }
 
 void UMLApp::setupZoomMenu() {
@@ -352,7 +364,7 @@ void UMLApp::setupZoomMenu() {
     m_zoomSelect->insertItem(i18n("3&00%"),300);
 
 
-    int zoom = m_doc->getCurrentView()->currentZoom();
+    int zoom = getCurrentView()->currentZoom();
     //if current zoom is not a "standard zoom" (because of zoom in / zoom out step
     //we add it for information
     switch(zoom){
@@ -458,6 +470,8 @@ void UMLApp::initView() {
 
     m_listDock = createDockWidget( "Model", 0L, 0L, i18n("&Tree View") );
     m_listView = new UMLListView(m_listDock ,"LISTVIEW");
+    m_listView->setDocument(m_doc);
+    m_listView->init();
     m_listDock->setWidget(m_listView);
     m_listDock->setDockSite(KDockWidget::DockCorner);
     m_listDock->manualDock(m_mainDock, KDockWidget::DockLeft, 20);
@@ -468,7 +482,6 @@ void UMLApp::initView() {
     m_documentationDock->setDockSite(KDockWidget::DockCorner);
     m_documentationDock->manualDock(m_listDock, KDockWidget::DockBottom, 80);
 
-    m_listView->setDocument(m_doc);
     m_doc->setupSignals();//make sure gets signal from list view
 
     readDockConfig(); //reposition all the DockWindows to their saved positions
@@ -707,6 +720,8 @@ void UMLApp::slotFileOpenRecent(const KURL& url) {
         if(!m_doc->openDocument(url)) {
             fileOpenRecent->removeURL(url);
             fileOpenRecent->setCurrentItem( -1 );
+        } else {
+            fileOpenRecent->addURL(url);
         }
         enablePrint(true);
         setCaption(m_doc->URL().fileName(), false);
@@ -807,6 +822,22 @@ void UMLApp::slotFileQuit() {
     slotStatusMsg(i18n("Ready."));
 }
 
+void UMLApp::slotFileExportDocbook()
+{
+  DocbookGenerator().generateDocbookForProject();
+}
+    
+void UMLApp::slotFileExportXhtml()
+{
+  if (m_xhtmlGenerator != 0)
+  {
+    return;
+  }
+  m_xhtmlGenerator = new XhtmlGenerator();
+  m_xhtmlGenerator->generateXhtmlForProject();
+  connect(m_xhtmlGenerator,SIGNAL(finished()),this,SLOT(slotXhtmlDocGenerationFinished()));
+}
+    
 void UMLApp::slotEditUndo() {
     m_doc->loadUndoData();
     slotStatusMsg(i18n("Ready."));
@@ -821,7 +852,7 @@ void UMLApp::slotEditCut() {
     slotStatusMsg(i18n("Cutting selection..."));
     //FIXME bug 59774 this fromview isn't very reliable.
     //when cutting diagrams it is set to true even though it shouldn't be
-    bool fromview = (m_doc->getCurrentView() && m_doc->getCurrentView()->getSelectCount());
+    bool fromview = (getCurrentView() && getCurrentView()->getSelectCount());
     if ( editCutCopy(fromview) ) {
         emit sigCutSuccessful();
         slotDeleteSelectedWidget();
@@ -832,7 +863,7 @@ void UMLApp::slotEditCut() {
 
 void UMLApp::slotEditCopy() {
     slotStatusMsg(i18n("Copying selection to clipboard..."));
-    bool  fromview = (m_doc->getCurrentView() && m_doc->getCurrentView()->getSelectCount());
+    bool  fromview = (getCurrentView() && getCurrentView()->getSelectCount());
     editCutCopy( fromview );
     slotStatusMsg(i18n("Ready."));
     m_doc -> setModified( true );
@@ -897,40 +928,49 @@ void UMLApp::slotStatusMsg(const QString &text) {
 }
 
 void UMLApp::slotClassDiagram() {
-    getDocument() -> createDiagram( Uml::dt_Class ) ;
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Logical);
+    getDocument()->createDiagram(root, Uml::dt_Class);
 }
 
 
 void UMLApp::slotSequenceDiagram() {
-    getDocument() -> createDiagram( Uml::dt_Sequence );
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Logical);
+    m_doc->createDiagram(root, Uml::dt_Sequence);
 }
 
 void UMLApp::slotCollaborationDiagram() {
-    getDocument() -> createDiagram( Uml::dt_Collaboration );
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Logical);
+    m_doc->createDiagram(root, Uml::dt_Collaboration);
 }
 
 void UMLApp::slotUseCaseDiagram() {
-    getDocument() -> createDiagram( Uml::dt_UseCase );
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_UseCase);
+    m_doc->createDiagram(root, Uml::dt_UseCase);
 }
 
 void UMLApp::slotStateDiagram() {
-    getDocument() -> createDiagram( Uml::dt_State );
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Logical);
+    m_doc->createDiagram(root, Uml::dt_State);
 }
 
 void UMLApp::slotActivityDiagram() {
-    getDocument() -> createDiagram( Uml::dt_Activity );
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Logical);
+    m_doc->createDiagram(root, Uml::dt_Activity);
 }
 
 void UMLApp::slotComponentDiagram() {
-    getDocument()->createDiagram( Uml::dt_Component );
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Component);
+    m_doc->createDiagram(root, Uml::dt_Component );
 }
 
 void UMLApp::slotDeploymentDiagram() {
-    getDocument()->createDiagram(Uml::dt_Deployment);
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_Deployment);
+    m_doc->createDiagram(root, Uml::dt_Deployment);
 }
 
 void UMLApp::slotEntityRelationshipDiagram() {
-    getDocument()->createDiagram(Uml::dt_EntityRelationship);
+    UMLFolder *root = m_doc->getRootFolder(Uml::mt_EntityRelationship);
+    m_doc->createDiagram(root, Uml::dt_EntityRelationship);
 }
 
 WorkToolBar* UMLApp::getWorkToolBar() {
@@ -943,7 +983,7 @@ void UMLApp::setModified(bool modified) {
     //if anything else needs to be done on a mofication, put it here
 
     // printing should be possible whenever there is something to print
-    if ( m_loading == false && modified == true && m_doc->getCurrentView() )  {
+    if ( m_loading == false && modified == true && getCurrentView() )  {
         enablePrint(true);
     }
 
@@ -1003,7 +1043,7 @@ void UMLApp::slotClipDataChanged() {
 }
 
 void UMLApp::slotCopyChanged() {
-    if(m_listView->getSelectedCount() || (m_doc->getCurrentView() && m_doc->getCurrentView()->getSelectCount())) {
+    if(m_listView->getSelectedCount() || (getCurrentView() && getCurrentView()->getSelectCount())) {
         editCopy->setEnabled(true);
         editCut->setEnabled(true);
     } else {
@@ -1076,13 +1116,7 @@ void UMLApp::readOptionState() {
     m_config -> setGroup( "General Options" );
     Settings::OptionState& optionState = Settings::getOptionState();
     optionState.generalState.undo = m_config -> readBoolEntry( "undo", true );
-    optionState.generalState.tabdiagrams = m_config -> readBoolEntry( "tabdiagrams",
-#if KDE_IS_VERSION(3,1,90)
-            true
-#else
-            false
-#endif
-                                                                      );
+    optionState.generalState.tabdiagrams = m_config -> readBoolEntry("tabdiagrams", false);
 #if defined (BUG84739_FIXED)
     optionState.generalState.newcodegen = m_config -> readBoolEntry("newcodegen", false);
 #else
@@ -1109,7 +1143,7 @@ void UMLApp::readOptionState() {
     optionState.generalState.logo = m_config -> readBoolEntry( "logo", true );
     optionState.generalState.loadlast = m_config -> readBoolEntry( "loadlast", true );
 
-    optionState.generalState.diagram  = ( Settings::Diagram ) m_config -> readNumEntry( "diagram", 1 );
+    optionState.generalState.diagram  = (Uml::Diagram_Type) m_config->readNumEntry("diagram", 1);
     m_config -> setGroup( "TipOfDay");
 
     optionState.generalState.tip = m_config -> readBoolEntry( "RunOnStart", true );
@@ -1308,21 +1342,21 @@ QString UMLApp::activeLanguageScopeSeparator() {
 }
 
 void UMLApp::slotCurrentViewClearDiagram() {
-    m_doc->getCurrentView()->clearDiagram();
+    getCurrentView()->clearDiagram();
 }
 
 void UMLApp::slotCurrentViewToggleSnapToGrid() {
-    m_doc->getCurrentView()->toggleSnapToGrid();
-    viewSnapToGrid->setChecked( m_doc->getCurrentView()->getSnapToGrid() );
+    getCurrentView()->toggleSnapToGrid();
+    viewSnapToGrid->setChecked( getCurrentView()->getSnapToGrid() );
 }
 
 void UMLApp::slotCurrentViewToggleShowGrid() {
-    m_doc->getCurrentView()->toggleShowGrid();
-    viewShowGrid->setChecked( m_doc->getCurrentView()->getShowSnapGrid() );
+    getCurrentView()->toggleShowGrid();
+    viewShowGrid->setChecked( getCurrentView()->getShowSnapGrid() );
 }
 
 void UMLApp::slotCurrentViewExportImage() {
-    m_doc->getCurrentView()->getImageExporter()->exportView();
+    getCurrentView()->getImageExporter()->exportView();
 }
 
 void UMLApp::slotAllViewsExportImage() {
@@ -1330,7 +1364,7 @@ void UMLApp::slotAllViewsExportImage() {
 }
 
 void UMLApp::slotCurrentViewProperties() {
-    m_doc->getCurrentView()->showPropDialog();
+    getCurrentView()->showPropDialog();
 }
 
 void UMLApp::setDiagramMenuItemsState(bool bState) {
@@ -1341,9 +1375,9 @@ void UMLApp::setDiagramMenuItemsState(bool bState) {
     viewExportImage->setEnabled( bState );
     viewProperties->setEnabled( bState );
     filePrint->setEnabled( bState );
-    if ( m_doc->getCurrentView() ) {
-        viewSnapToGrid->setChecked( m_doc->getCurrentView()->getSnapToGrid() );
-        viewShowGrid->setChecked( m_doc->getCurrentView()->getShowSnapGrid() );
+    if ( getCurrentView() ) {
+        viewSnapToGrid->setChecked( getCurrentView()->getSnapToGrid() );
+        viewShowGrid->setChecked( getCurrentView()->getShowSnapGrid() );
     }
 }
 
@@ -1414,13 +1448,11 @@ void UMLApp::slotAddDefaultDatatypes() {
 }
 
 void UMLApp::slotCurrentViewChanged() {
-    UMLView *viewAtDoc = m_doc->getCurrentView();
-    // FIXME: This whole business of UMLDoc::getCurrentView() vs.
-    //        UMLApp::getCurrentView() is a shame.
-    if (viewAtDoc) {
-        connect(viewAtDoc, SIGNAL( sigShowGridToggled(bool) ),
+    UMLView *view = getCurrentView();
+    if (view) {
+        connect(view, SIGNAL( sigShowGridToggled(bool) ),
                 this, SLOT( slotShowGridToggled(bool) ) );
-        connect(viewAtDoc, SIGNAL( sigSnapToGridToggled(bool) ),
+        connect(view, SIGNAL( sigSnapToGridToggled(bool) ),
                 this, SLOT( slotSnapToGridToggled(bool) ) );
     }
 }
@@ -1433,19 +1465,19 @@ void UMLApp::slotShowGridToggled(bool gridOn) {
 }
 
 void UMLApp::slotSelectAll() {
-    m_doc->getCurrentView()->selectAll();
+    getCurrentView()->selectAll();
 }
 
 void UMLApp::slotDeleteSelectedWidget() {
-    if ( m_doc->getCurrentView() ) {
-        m_doc->getCurrentView()->deleteSelection();
+    if ( getCurrentView() ) {
+        getCurrentView()->deleteSelection();
     } else {
         kdWarning() << " trying to delete widgets when there is no current view (see bug 59774)" << endl;
     }
 }
 
 void UMLApp::slotDeleteDiagram() {
-    m_doc->removeDiagram( m_doc->getCurrentView()->getID() );
+    m_doc->removeDiagram( getCurrentView()->getID() );
 }
 
 Uml::Programming_Language UMLApp::getDefaultLanguage() {
@@ -1583,15 +1615,14 @@ QWidget* UMLApp::getMainViewWidget() {
     return m_viewStack;
 }
 
-void UMLApp::setCurrentView(UMLView* view /*=0*/) {
+void UMLApp::setCurrentView(UMLView* view) {
     m_view = view;
     if (m_viewStack == NULL)
         return;
+    m_viewStack->raiseWidget(view);
+    kapp->processEvents();
     if (view) {
-        m_viewStack->raiseWidget(view);
         slotStatusMsg(view->getName());
-    } else {
-        m_viewStack->raiseWidget(blankWidget);
     }
 }
 
@@ -1656,6 +1687,12 @@ void UMLApp::slotAutolayout(){
 #endif
 }
 
+void UMLApp::slotXhtmlDocGenerationFinished()
+{
+  delete m_xhtmlGenerator;
+  m_xhtmlGenerator = 0;
+}
+
 KTabWidget* UMLApp::tabWidget() {
     return m_tabWidget;
 }
