@@ -57,6 +57,7 @@ class IDChangeLog;
 class ObjectWidget;
 class UMLWidget;
 class UMLPackage;
+class UMLFolder;
 
 /**
   * UMLDoc provides a document object for a document-view model.
@@ -87,6 +88,12 @@ public:
      */
     ~UMLDoc();
 
+    /**
+     * Initialize the UMLDoc.
+     * To be called after the constructor, before anything else.
+     */
+    void init();
+
     /**
      * Adds a view to the document which represents the document
      * contents. Usually this is your main view.
@@ -264,11 +271,12 @@ public:
     /**
      * Creates a diagram of the given type.
      *
+     * @param folder            The folder in which tp create the diagram.
      * @param type              The type of diagram to create.
      * @param askForName        If true shows a dialog box asking for name,
      *                  else uses a default name.
      */
-    void createDiagram(Uml::Diagram_Type type, bool askForName = true);
+    void createDiagram(UMLFolder *folder, Uml::Diagram_Type type, bool askForName = true);
 
     /**
      * Removes an @ref UMLObject from the current file.  If this object
@@ -403,22 +411,14 @@ public:
      */
     Uml::IDType getModelID() const;
 
-    /**
-     * Used to give a unique ID to any sort of object.
-     *
-     * @return  A new unique ID.
-     */
-    Uml::IDType getUniqueID();
-
     /**
      * This method is called for saving the given model as a XMI file.
      * It is virtual and calls the corresponding saveToXMI() functions
      * of the derived classes.
      *
      * @param file              The file to be saved to.
-     * @param saveSubmodelFiles True if external folders should be saved.
      */
-    virtual void saveToXMI(QIODevice& file, bool saveSubmodelFiles = false);
+    virtual void saveToXMI(QIODevice& file);
 
     /**
      * Checks the given XMI file if it was saved with correct Unicode
@@ -503,12 +503,12 @@ public:
     void signalUMLObjectCreated(UMLObject * o);
 
     /**
-     * Returns the current view.
+     * Returns the datatype folder.
      *
-     * @return  Pointer to the current UMLView.
+     * @return  Pointer to the predefined folder for datatypes.
      */
-    UMLView * getCurrentView() {
-        return m_currentView;
+    UMLFolder * getDatatypeFolder() {
+        return m_datatypeRoot;
     }
 
     /**
@@ -573,9 +573,7 @@ public:
      *
      * @return  List of UML views.
      */
-    const UMLViewList &getViewIterator() const {
-        return m_ViewList;
-    }
+    UMLViewList getViewIterator();
 
     /**
      * Assigns an already created UMLObject a new ID.
@@ -592,11 +590,9 @@ public:
      * any ids or signal.  Use AddUMLObjectPaste if pasting.
      *
      * @param object   The object to add.
-     * @param prepend  True if wish to prepend the object to the object list
-     *                 (default: append)
      * @return  True if the object was actually added.
      */
-    bool addUMLObject(UMLObject * object, bool prepend = false);
+    bool addUMLObject(UMLObject * object);
 
     /**
      * Adds an already created UMLView to the document, it gets
@@ -610,6 +606,34 @@ public:
      */
     bool addUMLView(UMLView * pView );
 
+    /**
+     * Return the predefined root folder of the given type.
+     */
+    UMLFolder *getRootFolder(Uml::Model_Type mt);
+
+    /**
+     * Return the corresponding Model_Type if the given object
+     * is one of the root folders.
+     * When the given object is not one of the root folders then
+     * return Uml::N_MODELTYPES.
+     */
+    Uml::Model_Type rootFolderType(UMLObject *obj);
+
+    /**
+     * Return the currently selected root folder.
+     * This will be an element from the m_root[] array.
+     */
+    UMLFolder *currentRoot();
+
+    /**
+     * Set the current root folder.
+     *
+     * @param rootType    The type of the root folder to set.
+     *                    The element from m_root[] which is indexed
+     *                    by this type is selected.
+     */
+    void setCurrentRoot(Uml::Model_Type rootType);
+
     /**
      * Read property of IDChangeLog* m_pChangeLog.
      *
@@ -658,8 +682,6 @@ public:
     /**
      * Activate all the diagrams/views after loading so all their
      * widgets keep their IDs.
-     *
-     * @return  True if operation successful.
      */
     void activateAllViews();
 
@@ -704,11 +726,6 @@ public:
      */
     void clearRedoStack();
 
-    /**
-     * All the UMLViews (i.e. diagrams)
-     */
-    UMLViewList m_ViewList;
-
     /**
      * Returns a name for the new object, appended with a number
      * if the default name is taken e.g. class diagram, class
@@ -770,15 +787,6 @@ public:
      */
     void writeToStatusBar(const QString &text);
 
-    /**
-     * Folders in the listview can be marked such that their contents
-     * are saved to a separate file.
-     * This method loads the separate folder file.
-     * CAVEAT: This is not XMI standard compliant.
-     * If standard compliance is an issue then avoid folder files.
-     */
-    bool loadFolderFile(QString filename);
-
     /**
      * Type resolution pass.
      */
@@ -796,7 +804,15 @@ private:
      */
     void initSaveTimer();
 
-    UMLObjectList m_objectList;
+    /**
+     * Array of predefined root folders.
+     */
+    UMLFolder *m_root[Uml::N_MODELTYPES];
+    /**
+     * Predefined root folder for datatypes, contained in
+     * m_root[Uml::mt_Logical]
+     */
+    UMLFolder *m_datatypeRoot;
 
     /**
      * The UMLDoc is the sole owner of all stereotypes.
@@ -807,21 +823,11 @@ private:
      */
     UMLStereotypeList m_stereoList;
 
-    /**
-     * In principle, each model object gets assigned a unique ID.
-     * NOTE: Currently this is an int although Uml::IDType is a string
-     *       (unless ID_USE_INT is defined.) Perhaps it should be changed
-     *       to Uml::IDType but then we need a unique string generator.
-     *       See also UMLView::m_nLocalID.
-     */
-    int m_uniqueID;
-
     QString m_Name; ///< name of this model as stored in the <UML:Model> tag
     Uml::IDType m_modelID; ///< xmi.id of this model in the <UML:Model>
     int m_count;   ///< auxiliary counter for the progress bar
     bool m_modified;
     KURL m_doc_url;
-    UMLView* m_currentView;
 
     /**
      * Contains all the UMLObject id changes of paste session.
@@ -883,19 +889,17 @@ private:
      */
     KPopupMenu* m_pTabPopupMenu;
 
+    /**
+     * Auxiliary variable for currentRoot():
+     * m_pCurrentRoot is only used if UMLApp::app()->getCurrentView()
+     * returns NULL.
+     */
+    UMLFolder * m_pCurrentRoot;
+
 public slots:
 
     void slotRemoveUMLObject(UMLObject*o);
 
-
-    /**
-     * Calls repaint() on all views connected to the document
-     * object and is called by the view by which the document has
-     * been changed.  As this view normally repaints itself, it is
-     * excluded from the paintEvent.
-     */
-    void slotUpdateAllViews(UMLView *sender);
-
     /**
      * Called after a specified time to autosave the document.
      */
