@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
  ***************************************************************************/
 
 #ifndef UMLNAMESPACE_H
@@ -24,6 +21,17 @@
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
 namespace Uml {
+
+enum Model_Type
+{
+    mt_Logical,
+    mt_UseCase,
+    mt_Component,
+    mt_Deployment,
+    mt_EntityRelationship,
+    N_MODELTYPES   // must remain last
+};
+
 enum Object_Type
 {
     ot_UMLObject  = 100,
@@ -45,7 +53,8 @@ enum Object_Type
     ot_Stereotype,
     ot_Role,
     ot_Entity,
-    ot_EntityAttribute
+    ot_EntityAttribute,
+    ot_Folder
 };
 
 class Visibility {
@@ -102,16 +111,16 @@ enum Diagram_Type
 {
     //the values in this enum are saved out to the file
     //for file compatibility, only add new values to the end
-    dt_UseCase  =  400,
-    dt_Collaboration,
+    dt_Undefined = 0,
     dt_Class,
+    dt_UseCase,
     dt_Sequence,
+    dt_Collaboration,
     dt_State,
     dt_Activity,
     dt_Component,
     dt_Deployment,
-    dt_EntityRelationship,
-    dt_Undefined = -1
+    dt_EntityRelationship
 };
 
 enum Association_Type
@@ -208,6 +217,53 @@ enum ListView_Type
     lvt_Unknown = -1
 };
 
+enum Icon_Type
+{
+    it_Home = 0,
+    it_Folder_Cyan,
+    it_Folder_Cyan_Open,
+    it_Folder_Green,
+    it_Folder_Green_Open,
+    it_Folder_Grey,
+    it_Folder_Grey_Open,
+    it_Folder_Red,
+    it_Folder_Red_Open,
+    it_Folder_Violet,
+    it_Folder_Violet_Open,
+    it_Folder_Orange,
+    it_Folder_Orange_Open,
+    it_Diagram, //change to have different one for each type of diagram
+    it_Class,
+    it_Template,
+    it_Package,
+    it_Subsystem,
+    it_Component,
+    it_Node,
+    it_Artifact,
+    it_Interface,
+    it_Datatype,
+    it_Enum,
+    it_Entity,
+    it_Actor,
+    it_UseCase,
+    it_Public_Method,
+    it_Private_Method,
+    it_Protected_Method,
+    it_Public_Attribute,
+    it_Private_Attribute,
+    it_Protected_Attribute,
+    it_Diagram_Activity,
+    it_Diagram_Class,
+    it_Diagram_Collaboration,
+    it_Diagram_Component,
+    it_Diagram_Deployment,
+    it_Diagram_EntityRelationship,
+    it_Diagram_Sequence,
+    it_Diagram_State,
+    it_Diagram_Usecase,
+    N_ICONTYPES    // must remain last
+};
+
 enum Changeability_Type
 {
     chg_Changeable = 900,
@@ -287,6 +343,6 @@ const IDType id_Reserved = "0";
  */
 bool tagEq (QString tag, QString pattern);
 
-}
+}  // end namespace Uml
 
 #endif
